# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_rx", "0003_alter_rxmodificationreasons_options_and_more"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="rxmodificationreasons",
            name="edc_rx_rxmo_name_b72a47_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodifications",
            name="edc_rx_rxmo_name_28fadc_idx",
        ),
    ]
